# DP: Proposed patch for PR ld/10340, ld doesn't honor sysroot prefix for ldscripts

Signed-off-by: Sven Rebhan <odinshorse@googlemail.com>

Always try to prepend the sysroot prefix to absolute filenames first.

--- a/ld/ldfile.c
+++ b/ld/ldfile.c
@@ -308,18 +308,24 @@
      directory first.  */
   if (! entry->is_archive)
     {
-      if (entry->sysrooted && IS_ABSOLUTE_PATH (entry->filename))
+      /* For absolute pathnames, try to always open the file in the
+	 sysroot first. If this fails, try to open the file at the
+	 given location. */
+      entry->sysrooted = is_sysrooted_pathname(entry->filename, FALSE);
+      if (IS_ABSOLUTE_PATH (entry->filename) && ld_sysroot && ! entry->sysrooted)
 	{
 	  char *name = concat (ld_sysroot, entry->filename,
 			       (const char *) NULL);
 	  if (ldfile_try_open_bfd (name, entry))
 	    {
 	      entry->filename = name;
+	      entry->sysrooted = TRUE;
 	      return TRUE;
 	    }
 	  free (name);
 	}
-      else if (ldfile_try_open_bfd (entry->filename, entry))
+
+      if (ldfile_try_open_bfd (entry->filename, entry))
 	{
 	  entry->sysrooted = IS_ABSOLUTE_PATH (entry->filename)
 	    && is_sysrooted_pathname (entry->filename, TRUE);
